@@ -1,7 +1,7 @@
 package Win32::FileOp;
 
 use vars qw($VERSION);
-$Win32::FileOp::VERSION = '0.11.3';
+$Win32::FileOp::VERSION = '0.12.1';
 
 use Win32::API;
 use File::Find;
@@ -11,7 +11,7 @@ use strict ;# 'vars';
 use Carp;
 
 #http://Jenda.Krynicky.cz/
-use Lazy;
+use Data::Lazy;
 use Win32::AbsPath qw(Relative2Absolute RelativeToAbsolute);
 
 require Exporter;
@@ -37,7 +37,7 @@ my @OFN_flags = qw(
 
 my @BIF_flags = qw(
      BIF_RETURNONLYFSDIRS BIF_DONTGOBELOWDOMAIN BIF_STATUSTEXT BIF_RETURNFSANCESTORS
-     BIF_BROWSEFORCOMPUTER BIF_BROWSEFORPRINTER BIF_BROWSEINCLUDEFILES 
+     BIF_BROWSEFORCOMPUTER BIF_BROWSEFORPRINTER BIF_BROWSEINCLUDEFILES
 );
 
 my @CSIDL_flags = qw(
@@ -65,6 +65,7 @@ my @CSIDL_flags = qw(
       Compress Uncompress UnCompress Compressed SetCompression GetCompression CompressedSize CompressDir UncompressDir UnCompressDir
       Map Unmap Disconnect Mapped
       Subst Unsubst Substed SubstDev
+	  GetLargeFileSize GetDiskFreeSpace
  ),
  @FOF_flags,
  @OFN_flags,
@@ -182,7 +183,7 @@ sub BIF_BROWSEINCLUDEFILES () { 0x4000 } #// Browsing for Everything
 #BIF_RETURNFSANCESTORS	Only returns file system ancestors. If the user
 #selects anything other than a file system ancestor, the OK button is
 #grayed.
- 
+
 #BIF_RETURNONLYFSDIRS	Only returns file system directories. If the
 #user selects folders that are not part of the file system, the OK button
 #is grayed.
@@ -244,191 +245,203 @@ sub DDD_NO_BROADCAST_SYSTEM     () { 0x00000008 }
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-tie $Win32::FileOp::fileop, 'Lazy', sub {
+tie $Win32::FileOp::fileop, 'Data::Lazy', sub {
   new Win32::API("shell32", "SHFileOperation", ['P'], 'I')
   or
   die "new Win32::API::SHFileOperation: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::copyfile, 'Lazy', sub {
+tie $Win32::FileOp::copyfile, 'Data::Lazy', sub {
   new Win32::API("KERNEL32", "CopyFile", [qw(P P I)], 'I')
   or
   die "new Win32::API::CopyFile: $!\n";
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::movefileexDel, 'Lazy', sub {
+tie $Win32::FileOp::movefileexDel, 'Data::Lazy', sub {
     new Win32::API("KERNEL32", "MoveFileEx", ['P','L','N'], 'I')
     or
     die "new Win32::API::MoveFileEx for delete: $!\n";
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::movefileex, 'Lazy', sub {
+tie $Win32::FileOp::movefileex, 'Data::Lazy', sub {
     new Win32::API("KERNEL32", "MoveFileEx", ['P','P','N'], 'I')
     or
     die "new Win32::API::MoveFileEx: $!\n";
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::SHAddToRecentDocs, 'Lazy', sub {
+tie $Win32::FileOp::SHAddToRecentDocs, 'Data::Lazy', sub {
     new Win32::API("shell32", "SHAddToRecentDocs", ['I','P'], 'I')
     or
     die "new Win32::API::SHAddToRecentDocs: $!\n";
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::SHAddToRecentDocs, 'Lazy', sub {
+tie $Win32::FileOp::SHAddToRecentDocs, 'Data::Lazy', sub {
     new Win32::API("shell32", "SHAddToRecentDocs", ['I','P'], 'I')
     or
     die "new Win32::API::SHAddToRecentDocs: $!\n";
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::writeINI, 'Lazy', sub {
+tie $Win32::FileOp::writeINI, 'Data::Lazy', sub {
     new Win32::API("KERNEL32", "WritePrivateProfileString", [qw(P P P P)], 'I')
     or
     die "new Win32::API::WritePrivateProfileString: $!\n"
 }, &LAZY_READONLY;
 
 
-tie $Win32::FileOp::writeWININI, 'Lazy', sub {
+tie $Win32::FileOp::writeWININI, 'Data::Lazy', sub {
     new Win32::API("KERNEL32", "WriteProfileString", [qw(P P P)], 'I')
     or
     die "new Win32::API::WriteProfileString: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::deleteINI, 'Lazy', sub {
+tie $Win32::FileOp::deleteINI, 'Data::Lazy', sub {
     new Win32::API("KERNEL32", "WritePrivateProfileString", [qw(P P L P)], 'I')
     or
     die "new Win32::API::WritePrivateProfileString for delete: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::deleteWININI, 'Lazy', sub {
+tie $Win32::FileOp::deleteWININI, 'Data::Lazy', sub {
     new Win32::API("KERNEL32", "WriteProfileString", [qw(P P L)], 'I')
     or
     die "new Win32::API::WriteProfileString for delete: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::readINI, 'Lazy', sub {
+tie $Win32::FileOp::readINI, 'Data::Lazy', sub {
     new Win32::API("KERNEL32", "GetPrivateProfileString", [qw(P P P P N P)], 'N')
     or
     die "new Win32::API::GetPrivateProfileString: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::readWININI, 'Lazy', sub {
+tie $Win32::FileOp::readWININI, 'Data::Lazy', sub {
     new Win32::API("KERNEL32", "GetProfileString", [qw(P P P P N)], 'N')
     or
     die "new Win32::API::GetProfileString: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::GetOpenFileName, 'Lazy', sub {
+tie $Win32::FileOp::GetOpenFileName, 'Data::Lazy', sub {
     new Win32::API("comdlg32", "GetOpenFileName", ['P'], 'N')
     or
     die "new Win32::API::GetOpenFileName: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::GetSaveFileName, 'Lazy', sub {
+tie $Win32::FileOp::GetSaveFileName, 'Data::Lazy', sub {
     new Win32::API("comdlg32", "GetSaveFileName", ['P'], 'N')
     or
     die "new Win32::API::GetSaveFileName: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::CommDlgExtendedError, 'Lazy', sub {
+tie $Win32::FileOp::CommDlgExtendedError, 'Data::Lazy', sub {
     new Win32::API("comdlg32", "CommDlgExtendedError", [], 'N')
     or
     die "new Win32::API::CommDlgExtendedError: $!\n"
 }, &LAZY_READONLY;
 
 
-tie $Win32::FileOp::CreateFile, 'Lazy', sub {
+tie $Win32::FileOp::CreateFile, 'Data::Lazy', sub {
     new Win32::API( "kernel32", "CreateFile", [qw(P N N P N N P)], 'N')
     or
     die "new Win32::API::DeviceIoControl: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::CloseHandle, 'Lazy', sub {
+tie $Win32::FileOp::CloseHandle, 'Data::Lazy', sub {
     new Win32::API( "kernel32", "CloseHandle", ['N'], 'N')
     or
     die "new Win32::API::CloseHandle: $!\n"
 };
 
-tie $Win32::FileOp::DeviceIoControl, 'Lazy', sub {
+tie $Win32::FileOp::GetFileSize, 'Data::Lazy', sub {
+    new Win32::API( "kernel32", "GetFileSize", ['N','P'], 'N')
+    or
+    die "new Win32::API::GetFileSize: $!\n"
+};
+
+tie $Win32::FileOp::GetDiskFreeSpaceEx, 'Data::Lazy', sub {
+    new Win32::API( "kernel32", "GetDiskFreeSpaceEx", ['P','P','P','P'], 'N')
+    or
+    die "new Win32::API::GetFileSize: $!\n"
+};
+
+tie $Win32::FileOp::DeviceIoControl, 'Data::Lazy', sub {
     new Win32::API( "kernel32", "DeviceIoControl", ['N', 'N', 'P', 'N', 'P', 'N', 'P', 'P'], 'N')
     or
     die "new Win32::API::DeviceIoControl: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::SHBrowseForFolder, 'Lazy', sub {
+tie $Win32::FileOp::SHBrowseForFolder, 'Data::Lazy', sub {
    new Win32::API("shell32", "SHBrowseForFolder", ['P'], 'N')
    or
    die "new Win32::API::SHBrowseForFolder: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::SHGetPathFromIDList, 'Lazy', sub {
+tie $Win32::FileOp::SHGetPathFromIDList, 'Data::Lazy', sub {
    new Win32::API("shell32", "SHGetPathFromIDList", ['N','P'], 'I')
    or
    die "new Win32::API::SHGetPathFromIDList: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::SHGetSpecialFolderLocation, 'Lazy', sub {
+tie $Win32::FileOp::SHGetSpecialFolderLocation, 'Data::Lazy', sub {
    new Win32::API("shell32", "SHGetSpecialFolderLocation", ['N','I','P'], 'I')
    or
    die "new Win32::API::SHGetSpecialFolderLocation: $!\n"
 }, &LAZY_READONLY;
 
 
-tie $Win32::FileOp::GetFileVersionInfoSize, 'Lazy', sub {
+tie $Win32::FileOp::GetFileVersionInfoSize, 'Data::Lazy', sub {
    new Win32::API( "version", "GetFileVersionInfoSize", ['P', 'P'], 'N')
    or
    die "new Win32::API::GetFileVersionInfoSize: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::GetFileVersionInfo, 'Lazy', sub {
+tie $Win32::FileOp::GetFileVersionInfo, 'Data::Lazy', sub {
    new Win32::API( "version", "GetFileVersionInfo", ['P', 'N', 'N', 'P'], 'N')
    or
    die "new Win32::API::GetFileVersionInfo: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::GetCompressedFileSize, 'Lazy', sub {
+tie $Win32::FileOp::GetCompressedFileSize, 'Data::Lazy', sub {
    new Win32::API("kernel32", "GetCompressedFileSize", ['P','P'], 'L')
    or
    die "new Win32::API::GetCompressedFileSize: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::VerQueryValue, 'Lazy', sub {
+tie $Win32::FileOp::VerQueryValue, 'Data::Lazy', sub {
    new Win32::API( "version", "VerQueryValue", ['P', 'P', 'P', 'P'], 'N')
    or
    die "new Win32::API::VerQueryValue: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::WNetAddConnection3, 'Lazy', sub {
+tie $Win32::FileOp::WNetAddConnection3, 'Data::Lazy', sub {
   new Win32::API("mpr.dll", "WNetAddConnection3", ['L','P','P','P','L'], 'L')
   or
   die "new Win32::API::WNetAddConnection3: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::WNetGetConnection, 'Lazy', sub {
+tie $Win32::FileOp::WNetGetConnection, 'Data::Lazy', sub {
   new Win32::API("mpr.dll", "WNetGetConnection", ['P','P','P'], 'L')
   or
   die "new Win32::API::WNetGetConnection: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::WNetCancelConnection2, 'Lazy', sub {
+tie $Win32::FileOp::WNetCancelConnection2, 'Data::Lazy', sub {
   new Win32::API("mpr.dll", "WNetCancelConnection2", ['P','L','I'], 'L')
   or
   die "new Win32::API::WNetCancelConnection2: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::GetLogicalDrives, 'Lazy', sub {
+tie $Win32::FileOp::GetLogicalDrives, 'Data::Lazy', sub {
   new Win32::API("kernel32.dll", "GetLogicalDrives", [], 'N')
   or
   die "new Win32::API::GetLogicalDrives: $!\n"
 }, &LAZY_READONLY;
 
 
-tie $Win32::FileOp::QueryDosDevice, 'Lazy', sub {
+tie $Win32::FileOp::QueryDosDevice, 'Data::Lazy', sub {
   new Win32::API("kernel32.dll", "QueryDosDevice", ['P','P','L'], 'L')
   or
   die "new Win32::API::QueryDosDevice: $!\n"
 }, &LAZY_READONLY;
 
-tie $Win32::FileOp::DefineDosDevice, 'Lazy', sub {
+tie $Win32::FileOp::DefineDosDevice, 'Data::Lazy', sub {
   new Win32::API("kernel32.dll", "DefineDosDevice", ['L','P','P'],'I')
   or
   die "new Win32::API::DefineDosDevice: $!\n"
@@ -876,7 +889,7 @@ sub ReadINISections {
     undef $Win32::FileOp::Error;
     my $INI = shift;$INI='win.ini' unless $INI;$INI .= "\0";
     my $section = 0; # pass null to API
-	my $name = 0; 
+	my $name = 0;
 	my $default = "\0";
 	my @values;
 
@@ -942,7 +955,7 @@ sub OpenOrSaveDialog {
 
     $params->{handle} = 'self' unless exists $params->{handle};
     $params->{options} = 0 unless exists $params->{options};
-    
+
 
     my $lpstrFilter = '';
     if (UNIVERSAL::isa($params->{filters}, "HASH")) {
@@ -967,7 +980,7 @@ local $^W = 0;
 
     my $nFilterIndex = $params->{defaultfilter};
     $nFilterIndex = 1 unless $nFilterIndex>0; # to be sure it's a reasonable number
-    
+
     my $lpstrFile = $params->{filename}."\0".
     ($params->{options} & OFN_ALLOWMULTISELECT
      ? ' ' x ($Win32::FileOp::BufferSize - length $params->{filename})
@@ -1054,7 +1067,7 @@ sub BrowseForFolder {
        $lpszTitle, $nFolder, $ulFlags,
        $lpfn, $lParam, $iImage, $pszPath)
       =
-      (GetWindowHandle(), "\0"x260, " "x260,
+      (GetWindowHandle(), "\0"x260, "\0"x260,
        shift() || "\0", shift() || 0, (shift() || 0) | 0x0000,
        0, 0, 0, "\0"x260);
 
@@ -1062,7 +1075,7 @@ sub BrowseForFolder {
 
    $Win32::FileOp::SHGetSpecialFolderLocation->Call($hwndOwner, $nFolder, $pidlRoot)
    and return undef;
-   $pidlRoot =~ s/\0.*$//s;
+#   $pidlRoot =~ s/\0.*$//s;
    $pidlRoot = hex unpack 'H*',(join'', reverse split//, $pidlRoot);
 
    my $browseinfo = pack 'LLppILLI',
@@ -1076,7 +1089,7 @@ sub BrowseForFolder {
 
    $pszPath =~ s/\0.*$//s;
    $bool ? $pszPath : undef;
-}      
+}
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
@@ -1153,7 +1166,7 @@ sub SetCompression {
 #     $handle = $Win32::FileOp::CreateFile->Call($file, FILE_FLAG_WRITE_THROUGH | FILE_FLAG_OVERLAPPED,
 #     FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE, 0,
 #     OPEN_EXISTING, FILE_FLAG_BACKUP_SEMANTICS, 0);
-     
+
      if($handle != -1) {
          my $br = pack("L", 0);
          my $inbuffer = pack("S", $flag);
@@ -1237,6 +1250,54 @@ sub CompressDir {
 
 #- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
+sub GetLargeFileSize {
+    undef $Win32::FileOp::Error;
+    my ($file) = @_;
+    my $permission = hex('80000000') | hex('40000000');
+    my $handle = $Win32::FileOp::CreateFile->Call($file, $permission, 0, 0, 3, 0, 0);
+    if($handle != -1) {
+        my $buff = "\0" x 4;
+        my $size1 = $Win32::FileOp::GetFileSize->Call(
+            $handle, $buff
+        );
+        $Win32::FileOp::CloseHandle->Call($handle);
+		if (wantarray()) {
+			return ($size1,unpack('N',$buff));
+		} else {
+			return unpack('N',$buff)*0xFFFFFFFF + $size1
+		}
+    } else {
+        $Win32::FileOp::Error = "CreateFile failed: ",
+         Win32::FormatMessage(Win32::GetLastError);
+        return undef;
+    }
+}
+
+sub GetDiskFreeSpace {
+    undef $Win32::FileOp::Error;
+    my ($file) = @_;
+	$file .= '\\' if $file =~ /^\\\\/ and $file !~ /\\$/;
+	$file .= ':' if $file =~ /^[a-zA-Z]$/;
+    my ($freePerUser,$total, $free) = ("\x0" x 8) x 3;
+
+	$Win32::FileOp::GetDiskFreeSpaceEx->Call($file, $freePerUser,$total, $free)
+		or return;
+
+	if (wantarray()) {
+		my @res;
+		for ($freePerUser,$total, $free) {
+			my ($lo,$hi) = unpack('LL',$_);
+			push @res, ($hi & 0xFFFFFFFF) * 0xFFFFFFFF + ($lo & 0xFFFFFFFF);
+		}
+		return @res;
+	} else {
+		my ($lo,$hi) = unpack('LL',$freePerUser);
+		return ($hi & 0xFFFFFFFF) * 0xFFFFFFFF + ($lo & 0xFFFFFFFF);
+	}
+}
+
+#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
 sub FreeDriveLetters {
    undef $Win32::FileOp::Error;
    my (@dr, $i);
@@ -1276,7 +1337,7 @@ sub Map {
     if ($res == 1202 and $opt->{overwrite}) {
         Unmap($disk);
         $Win32::FileOp::WNetAddConnection3->Call(GetDesktopHandle(),$struct,$username,$passwd,$options)
-         and return;
+			and return;
     } else {
         return;
     }
@@ -1385,13 +1446,13 @@ sub Substed {
    or return;
 
   $path =~ s/\0.*$//;
-  
+
   $path =~ s/^\\\?\?\\UNC/\\/ and $device = 'UNC'
   or
   $path =~ s/\\Device\\(.*?)\\\w:/\\/ and $device = $1
   or
   $path =~ s/\\Device\\(.*)$// and $device = $1;
-  
+
   return wantarray ? ($path,$device) : $path;
  } else {
   my ($drive,$path,%data);
@@ -1434,16 +1495,17 @@ __END__
 
 =head1 NAME
 
- Win32::FileOp - 0.11.3
+ Win32::FileOp - 0.12.1
 
 =head1 DESCRIPTION
 
 Module for file operations with fancy dialog boxes, for moving files
 to recycle bin, reading and updating INI files and file operations in general.
 
-Unless mentioned otherwise all functions work both under WinNT and Win9x.
+Unless mentioned otherwise all functions work under WinXP, Win2k, WinNT, WinME and Win9x.
+Let me know if not.
 
-Version 0.11.3
+Version 0.12.1
 
 =head2 Functions
 
@@ -1464,9 +1526,11 @@ C<UpdateDir> C<FillInDir>
 C<Compress> C<Uncompress> C<Compressed> C<SetCompression> C<GetCompression>
 C<CompressDir> C<UncompressDir>
 
+C<GetLargeFileSize> C<GetDiskFreeSpace>
+
 C<AddToRecentDocs> C<EmptyRecentDocs>
 
-C<WriteToINI> C<WriteToWININI> C<ReadINI> C<ReadWININI> 
+C<WriteToINI> C<WriteToWININI> C<ReadINI> C<ReadWININI>
 
 C<DeleteFromINI> C<DeleteFromWININI>
 
@@ -1723,7 +1787,7 @@ fo the file).
 
 It doesn't compress all files and subdirectories in a directory you
 specify. Use ComressDir for that. Compress($directory) only sets the compression flag for
-the directory so that the new files are compressed by default. 
+the directory so that the new files are compressed by default.
 
 WinNT only!
 
@@ -1775,7 +1839,33 @@ in File::Find. That is $_, $File::Find::dir and $File::Find::name.
 
  UncompressDir $directory, ... [, \&callback]
 
-The counterpart of CompressDir. 
+The counterpart of CompressDir.
+
+=item GetLargeFileSize
+
+	($lo_word, $hi_word) = GetLargeFileSize( $path );
+	# or
+	$file_size = GetLargeFileSize( $path );
+
+This gives you the file size for too big files (over 4GB).
+If called in list context returns the two 32 bit words, in scalar context
+returns the file size as one number ... if the size is too big to fit in
+an Integer it'll be returned as a Float. This means that if it's above
+cca. 10E15 it may get slightly rounded.
+
+=item GetDiskFreeSpace
+
+	$freeSpaceForUser = GetDiskFreeSpace $path;
+	# or
+	($freeSpaceForUser, $totalSize, $totalFreeSpace) = GetDiskFreeSpace $path;
+
+In scalar context returns the amount of free space available to current user
+(respecting quotas), in list context returns the free space for current user, the total size
+of disk and the total amount of free space on the disk.
+
+Works OK with huge disks.
+
+Requires at least Windows 95 OSR2 or WinNT 4.0.
 
 =item AddToRecentDocs
 
@@ -1984,7 +2074,7 @@ $drive_or_share specifies the name of either the redirected local device
 or the remote network resource to disconnect from. If this parameter
 specifies a redirected local resource, only the specified redirection is
 broken; otherwise, all connections to the remote network resource are
-broken. 
+broken.
 
  Options:
   persistent = 0/1, if you do not use persistent=>1, the connection will be closed, but
@@ -2142,7 +2232,7 @@ box. If this flag is specified, the OFN_PATHMUSTEXIST flag is also used.
 
 Hides the Read Only check box.
 
- OFN_LONGNAMES    
+ OFN_LONGNAMES
 
 For old-style dialog boxes, this flag causes the dialog box to use long
 filenames. If this flag is not specified, or if the OFN_ALLOWMULTISELECT
@@ -2150,7 +2240,7 @@ flag is also set, old-style dialog boxes use short filenames (8.3
 format) for filenames with spaces. Explorer-style dialog boxes ignore
 this flag and always display long filenames.
 
- OFN_NOCHANGEDIR    
+ OFN_NOCHANGEDIR
 
 Restores the current directory to its original value if the user changed
 the directory while searching for files.
@@ -2161,7 +2251,7 @@ Directs the dialog box to return the path and filename of the selected
 shortcut (.LNK) file. If this value is not given, the dialog box returns
 the path and filename of the file referenced by the shortcut
 
- OFN_NOLONGNAMES    
+ OFN_NOLONGNAMES
 
 For old-style dialog boxes, this flag causes the dialog box to use short
 filenames (8.3 format). Explorer-style dialog boxes ignore this flag and
@@ -2176,7 +2266,7 @@ Hides and disables the Network button.
 Specifies that the returned file does not have the Read Only check box
 checked and is not in a write-protected directory.
 
- OFN_NOTESTFILECREATE    
+ OFN_NOTESTFILECREATE
 
 Specifies that the file is not created before the dialog box is closed.
 This flag should be specified if the application saves the file on a
@@ -2186,35 +2276,35 @@ open drive door, or network protection. Applications using this flag
 must perform file operations carefully, because a file cannot be
 reopened once it is closed.
 
- OFN_NOVALIDATE    
+ OFN_NOVALIDATE
 
 Specifies that the dialog boxes allow invalid characters in the returned
-filename. 
+filename.
 
- OFN_OVERWRITEPROMPT    
+ OFN_OVERWRITEPROMPT
 
 Causes the Save As dialog box to generate a message box if the selected
 file already exists. The user must confirm whether to overwrite the
 file.
 
- OFN_PATHMUSTEXIST    
+ OFN_PATHMUSTEXIST
 
 Specifies that the user can type only valid paths and filenames. If this
 flag is used and the user types an invalid path and filename in the File
 Name entry field, the dialog box function displays a warning in a
 message box.
 
- OFN_READONLY    
+ OFN_READONLY
 
 Causes the Read Only check box to be checked initially when the dialog
 box is created. If the check box is checked when the dialog box is closed
 $Win32::FileOp::ReadOnly is set to true.
 
- OFN_SHAREAWARE    
+ OFN_SHAREAWARE
 
 Specifies that if a call to the OpenFile function fails because of a
 network sharing violation, the error is ignored and the dialog box
-returns the selected filename. 
+returns the selected filename.
 
  OFN_SHOWHELP
 
@@ -2256,7 +2346,7 @@ printer, the OK button is grayed.
  BIF_STATUSTEXT
 
 Since it is currently impossible to define callbacks, this options is
-useless. 
+useless.
 
 
 =item CSIDL_
@@ -2377,7 +2467,7 @@ variable is ignored.
 All the functions keep Win32::API handles between calls. If you want to free the handles
 you may undefine them, but NEVER EVER set them to anything else than undef !!!
 Even  "$handlename = $handlename;" would destroy the handle without repair!
-See docs for Lazy.pm for explanation.
+See docs for Data::Lazy.pm for explanation.
 
 List of handles and functions that use them:
 
@@ -2444,7 +2534,7 @@ WNetConnectionDialog, WNetDisconnectDialog
  Module built by :
   Jan Krynicky <Jenda@Krynicky.cz>
   $Bill Luebkert <dbe@wgn.net>
-  Mike Blazer <blazer@mail.nevalink.ru>
+  Mike Blazer <blazer@peterlink.ru>
   Aldo Calpini <a.calpini@romagiubileo.it>
   Michael Yamada <myamada@gj.com>
 
